==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PageChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PageChangedEventArgsDescription } from "./PageChangedEventArgsDescription";
/**
 * @hidden
 */
var PageChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PageChangedEventArgsDescriptionMetadata, _super);
    function PageChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PageChangedEventArgsDescriptionMetadata.b = function (a) {
        if (PageChangedEventArgsDescriptionMetadata.a == null) {
            PageChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PageChangedEventArgsDescriptionMetadata.c(PageChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(PageChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(PageChangedEventArgsDescriptionMetadata.a);
    };
    PageChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Page", "Number:int");
        a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
    };
    PageChangedEventArgsDescriptionMetadata.d = function (a) {
        PageChangedEventArgsDescriptionMetadata.b(a);
        a.u("PageChangedEventArgs", function () { return new PageChangedEventArgsDescription(); });
        a.t("PageChangedEventArgs", PageChangedEventArgsDescriptionMetadata.a);
    };
    PageChangedEventArgsDescriptionMetadata.$t = markType(PageChangedEventArgsDescriptionMetadata, 'PageChangedEventArgsDescriptionMetadata');
    PageChangedEventArgsDescriptionMetadata.a = null;
    return PageChangedEventArgsDescriptionMetadata;
}(Base));
export { PageChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PageChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PageChangedEventArgsDescription } from "./PageChangedEventArgsDescription";
/**
 * @hidden
 */
var PageChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PageChangedEventArgsDescriptionMetadata, _super);
    function PageChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PageChangedEventArgsDescriptionMetadata.b = function (a) {
        if (PageChangedEventArgsDescriptionMetadata.a == null) {
            PageChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PageChangedEventArgsDescriptionMetadata.c(PageChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(PageChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(PageChangedEventArgsDescriptionMetadata.a);
    };
    PageChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Page", "Number:int");
        a.item("DataRef", "(w:Data,wf:Data)DataRef:object");
    };
    PageChangedEventArgsDescriptionMetadata.d = function (a) {
        PageChangedEventArgsDescriptionMetadata.b(a);
        a.aa("PageChangedEventArgs", function () { return new PageChangedEventArgsDescription(); });
        a.z("PageChangedEventArgs", PageChangedEventArgsDescriptionMetadata.a);
    };
    PageChangedEventArgsDescriptionMetadata.$t = markType(PageChangedEventArgsDescriptionMetadata, 'PageChangedEventArgsDescriptionMetadata');
    PageChangedEventArgsDescriptionMetadata.a = null;
    return PageChangedEventArgsDescriptionMetadata;
}(Base));
export { PageChangedEventArgsDescriptionMetadata };
